/// This dofile imports and cleans raw data, fills in missing values, and merges the data to produce "${cleaned}/CLEANED.dta" for analysis

****CEPEJ Court Budget****
import excel "${raw}/Map All budget.xlsx", sheet("Sheet 1") cellrange(E1:H50) firstrow case(lower) clear
//Generate country code
keep countryen_fr standardisednumeric
generate year=2020
kountry countryen_fr, from(other) stuck
rename _ISO3N_ iso3n
kountry iso3n, from(iso3n) to(iso3c)
drop iso3n
rename _ISO3C_ code
//Fill in missing code
replace code="MKD" if country=="North Macedonia"
replace code="MNE" if country=="Montenegro"
replace code="GBR-ENG&WAL" if country=="UK - England and Wales"
replace code="GBR-SCO" if country=="UK - Scotland"
replace code="GBR-NIR" if country=="UK - Northern Ireland"
//Format
rename countryen_fr country
rename standardisednumeric budget_gdp
gen source="CEPEJ Total Budget"
label variable country "Country Name"
label variable source "Data Source"
label variable budget_gdp "Budget as a Share of GDP"
label variable code "Country Code"
drop if budget_gdp==.
order country code year budget_gdp source
//Save as .dta
save "${cleaned}/CEPEJ.dta", replace

****COFOG Court Budget****
import excel "${raw}/Expenditure_by_Functions_of_Governm.xlsx", sheet("Data") cellrange(A1:BH2) firstrow clear
drop A
xpose, clear varname format
rename v1 budget_gdp
rename _varname country
//Generate country code
kountry country, from(other) stuck
rename _ISO3N_ iso3n
kountry iso3n, from(iso3n) to(iso3c)
drop iso3n
rename _ISO3C_ code
//Fill in missing code
replace code="TUR" if country=="TürkiyeRepof"
replace code="XKX" if country=="KosovoRepof"
replace code="BLR" if country=="BelarusRepof"
replace code="ARM" if country=="ArmeniaRepof"
replace code="HRV" if country=="CroatiaRepof"
replace code="AZE" if country=="AzerbaijanRepof"
replace code="EST" if country=="EstoniaRepof"
replace code="KAZ" if country=="KazakhstanRepof"
replace code="SVN" if country=="SloveniaRepof"
replace code="POL" if country=="PolandRepof"
replace code="SMR" if country=="San MarinoRepof"
replace code="SVK" if country=="SlovakRep"
replace code="HKG" if country=="ChinaPRHongKong"
replace code="MDA" if country=="MoldovaRepof"
replace code="GBR" if country=="UnitedKingdom"
replace code="KGZ" if country=="KyrgyzRep"
replace code="SLV" if country=="ElSalvador"
replace code="SMR" if country=="SanMarinoRepof"
replace code="RUS" if country=="RussianFederation"
replace code="ZAF" if country=="SouthAfrica"
//Format
replace budget_gdp=budget_gdp/100
gen source="COFOG"
label variable country "Country Name"
label variable source "Data Source"
label variable budget_gdp "Budget as a Share of GDP"
label variable code "Country Code"
gen year=2020
label variable year "Year"
order country code year budget_gdp source
//Save as .dta
save "${cleaned}/COFOG.dta", replace

****ODI Court Budget****
import excel "${raw}/Domestic_Financing_Data_-_for_website.xlsx", sheet("Summary data") cellrange(B2:R443) firstrow case(lower) clear
//Generate budget_gdp
drop if n==.
generate budget_gdp= real(govrevgdp)*n/10000
//Format
keep if year=="2020" | year=="FY 2020" |year=="20/21" |year=="FY 20/21"
drop year
gen year=2020
keep economy code budget_gdp year
rename economy country
gen source="ODI"
label variable country " Country Name"
label variable code "Country Code"
label variable source "Data Source"
label variable budget_gdp "Budget as a Share of GDP"
label variable year "Year"
//Save as .dta
save "${cleaned}/ODI.dta", replace

****WB Court Budget (National Budget Document)****
import excel "${raw}/Court Budget_Percentage of GDP_v5_Updated URLs.xlsx", sheet("ALL - Consolidated") firstrow case(lower) clear
//Format
keep if source!="CEPEJ" & source!="ODI - IMF Law Courts" & source!="IMF GFS" & source!="ODI - National budget" & source!="Budget information shared with CEPEJ"
replace source="National Budget Document"
keep country code courtbudgetasofgdp year source
rename courtbudgetasofgdp budget_gdp
label variable country "Country Name"
label variable code "Country Code"
label variable source "Data Source"
label variable budget_gdp "Budget as a Share of GDP"
order country code year budget_gdp source
//Save as .dta
save "${cleaned}/WB_NBD.dta", replace

****BOOST Court Budget****
//Prepare GDP in LCU for budget/GDP calculation
import excel "${raw}/P_Data_Extract_From_World_Development_Indicators (1).xlsx", sheet("Data") firstrow case(lower) clear
keep countryname countrycode yr2020
rename countryname country
rename countrycode code
rename yr2020 gdp_lcu
label variable gdp_lcu "GDP (LCU 2020)"
drop if code==""
save "${cleaned}/WB_GDP_LCU.dta", replace
//Import BOOST court budget data
import excel "${raw}/boost.xlsx", firstrow case(lower) clear
keep code country r
set type double
generate budget=real(r)
drop if budget==.
replace code="XKX" if country=="Kosovo"
replace code="TON" if country=="Tonga"
//Merge with WB_GDP_LCU.dta
merge 1:1 code using "${cleaned}/WB_GDP_LCU.dta", keep(3) nogen
gen budget_gdp= budget/real(gdp_lcu)
drop if budget_gdp==.
drop if country=="Sierra Leone" //Unreasonably high
//Format
gen year=2020
gen source="BOOST"
keep country code year budget_gdp source
order country code year budget_gdp source
label variable country "Country Name"
label variable code "Country Code"
label variable year "Year"
label variable source "Data Source"
label variable budget_gdp "Budget as a Share of GDP"
//Save as .dta
save "${cleaned}/BOOST.dta", replace

****WEO Government Expenditure****
import delimited "${raw}/WEOApr2024all.xls", clear 
///Keep government expenditure
keep iso country subjectdescriptor units v50
keep if subjectdescriptor=="General government total expenditure"
keep if units=="Percent of GDP"
//Format
keep iso country v50
rename iso code
rename v50 weo_gov_exp_gdp_100
gen year=2020
gen source="WEO"
label variable code "Country Code"
label variable country "Country Name"
label variable weo_gov_exp_gdp_100 "Government Total Expenditure as Percent of GDP"
label variable year "Year"
label variable source "Data Source"
replace code="XKX" if country=="Kosovo" //For consistent country code
save "${cleaned}/WEO_GOV_EXP.dta", replace

****WB Government Expenditure****
import excel "${raw}/P_Data_Extract_From_World_Development_Indicators (4).xlsx", sheet("Data") firstrow case(lower) clear
keep countryname countrycode yr2020
rename countryname country
rename countrycode code
rename yr2020 wb_gov_exp_gdp_100
drop if code==""
label variable wb_gov_exp_gdp_100 "General government final consumption expenditure (% of GDP)"
gen source="WB"
label variable source "Data Source"
save "${cleaned}/WB_GOV_EXP.dta", replace

****WB GDP per Capita****
import excel "${raw}/P_Data_Extract_From_World_Development_Indicators (2).xlsx", sheet("Data") firstrow case(lower) clear
keep countryname countrycode yr2020
rename countryname country
rename countrycode code
rename yr2020 gdp_per_capita
label variable gdp_per_capita "GDP per capita (Current US$)"
drop if code==""
save "${cleaned}/GDP_PC.dta", replace

****WB Income and Region Classification****
use "${raw}/Historical-data.dta", clear
keep if dbyear==2020
keep cod region incomegroup
drop if substr(cod,4,1)=="_"
drop if region==""
rename cod code
replace code="COD" if code=="ZAR" //For consistent country code
replace code="PSE" if code=="WBG" //For consistent country code
replace code="ROU" if code=="ROM" //For consistent country code
replace code="TLS" if code=="TMP" //For consistent country code
replace code="XKX" if code=="KSV" //For consistent country code
save "${cleaned}/WB_GROUP.dta", replace

****Court Budget/Government Expenditure 2020****
//For figure 1: Merge all sources
clear
append using "${cleaned}/BOOST.dta"
append using "${cleaned}/CEPEJ.dta"
append using "${cleaned}/COFOG.dta"
append using "${cleaned}/ODI.dta"
append using "${cleaned}/WB_NBD.dta"
order code country year budget_gdp source
merge m:1 code using "${cleaned}/WEO_GOV_EXP.dta", keep(1 3) nogen
merge m:1 code using "${cleaned}/WB_GOV_EXP.dta", keep(1 3) nogen
merge m:1 code using "${cleaned}/GDP_PC.dta", keep(1 3) nogen
merge m:1 code using "${cleaned}/WB_GROUP.dta", keep(1 3) nogen
//Manually fill in the missing income and region
replace region="Europe & Central Asia" if country=="Andorra"
replace region="Europe & Central Asia" if country=="Monaco"
replace region="East Asia & Pacific" if country=="Tuvalu"
replace region="High income: OECD" if country=="Chile"
replace incomegroup="High income" if country=="Andorra"
replace incomegroup="High income" if country=="Monaco"
replace incomegroup="Upper middle income" if country=="Tuvalu"
//Generate the "Court Budget as % of Gov't Exp." based on predetermined priority order
gen budget_gov_exp_100_weo= budget_gdp*10000/real(weo_gov_exp_gdp_100)
gen budget_gov_exp_100_wb= budget_gdp*10000/real(wb_gov_exp_gdp_100)
replace budget_gov_exp_100_weo=. if budget_gov_exp_100_weo==0
replace budget_gov_exp_100_wb=. if budget_gov_exp_100_wb==0
generate budget_gov_exp_100_wb_weo= budget_gov_exp_100_wb
replace budget_gov_exp_100_wb_weo= budget_gov_exp_100_weo if budget_gov_exp_100_wb==. & budget_gov_exp_100_weo!=.
gen priority_total=0 if source=="National Budget Document" & budget_gov_exp_100_wb_weo !=.
replace priority_total=1 if source=="CEPEJ Total Budget" & budget_gov_exp_100_wb_weo!=.
replace priority_total=2 if source=="COFOG" & budget_gov_exp_100_wb_weo!=.
replace priority_total=3 if source=="ODI" & budget_gov_exp_100_wb_weo!=.
replace priority_total=5 if source=="BOOST" & budget_gov_exp_100_wb_weo!=.
bysort code: egen priority_total_min=min(priority_total)
gen wb_weo=1 if priority_total==priority_total_min & priority_total!=.
keep if wb_weo==1
label variable budget_gov_exp_100_wb_weo "Court Budget as % of Gov't Exp." 
//Clean the GDP per capita data
destring gdp_per_capita, replace
gen log_gdp_per_capita=log(real(gdp_per_capita))
label variable log_gdp_per_capita "Log of GDP per capita (Current US$)"
//Format
keep code country year source budget_gov_exp_100_wb_weo log_gdp_per_capita region incomegroup
save "${cleaned}/BUDGET_GOV_EXP_2020.dta", replace


****judicial budget 2017-2022****
//Prepare government expenditure/gdp for budget/expenditure calculation
import excel "${raw}/P_Data_Extract_From_World_Development_Indicators (3).xlsx", sheet("Data") firstrow case(lower) clear
drop seriesname seriescode
rename countryname country
rename countrycode code
rename yr2017 gov2017
rename yr2018 gov2018
rename yr2019 gov2019
rename yr2020 gov2020
rename yr2021 gov2021
rename yr2022 gov2022
label variable gov2017 "General government final consumption expenditure (current LCU) 2017"
label variable gov2018 "General government final consumption expenditure (current LCU) 2018"
label variable gov2019 "General government final consumption expenditure (current LCU) 2019"
label variable gov2020 "General government final consumption expenditure (current LCU) 2020"
label variable gov2021 "General government final consumption expenditure (current LCU) 2021"
label variable gov2022 "General government final consumption expenditure (current LCU) 2022"
drop if code==""
save "${cleaned}/WB_GOV_EXP_1722.dta", replace
//Import BOOST court budget data
import excel "${raw}/boost.xlsx", firstrow case(lower) clear
keep code country executed o p q r s t
rename o judicial2017
rename p judicial2018
rename q judicial2019
rename r judicial2020
rename s judicial2021
rename t judicial2022
drop executed
replace code = "TON" if country=="Tonga"
replace code = "XKX" if country=="Kosovo"
//Merge with WB_GDP_LCU.dta
merge 1:1 code using "${cleaned}/WB_GOV_EXP_1722.dta", keep(1 3) nogen
merge 1:1 code using "${cleaned}/BUDGET_GOV_EXP_2020.dta", nogen
//Calculate the pre- & post-covid means
foreach y in 2017 2018 2019 2021 2022 {
	gen court_gov`y'=real(judicial`y')/real(gov`y')
	replace court_gov`y'=100*court_gov`y'
	replace court_gov`y'=. if country=="Sierra Leone"
}
gen court_gov2020=budget_gov_exp_100_wb_weo
drop budget_gov_exp_100_wb_weo
//Expand the datasets to have pre- & post-covid means in the same column
expand 2, gen(expand)
rename expand pre_post_covid
egen pre_covid=rowmean(court_gov2017 court_gov2018 court_gov2019)
egen post_covid=rowmean(court_gov2020 court_gov2021 court_gov2022)
generate pre_post_covid_means=pre_covid if pre_post_covid==0
replace pre_post_covid_means=post_covid if pre_post_covid==1
//Format
keep code country court_gov2017 court_gov2018 court_gov2019 court_gov2020 court_gov2021 court_gov2022 pre_covid post_covid pre_post_covid pre_post_covid_means year source region incomegroup log_gdp_per_capita
label variable court_gov2017 "Court Budget as % of Gov't Exp. 2017"
label variable court_gov2018 "Court Budget as % of Gov't Exp. 2018"
label variable court_gov2019 "Court Budget as % of Gov't Exp. 2019"
label variable court_gov2020 "Court Budget as % of Gov't Exp. 2020"
label variable court_gov2021 "Court Budget as % of Gov't Exp. 2021"
label variable court_gov2022 "Court Budget as % of Gov't Exp. 2022"
label define pre_post_covid 0 "2017-2019" 1 "2020-2022"
label values pre_post_covid pre_post_covid
label variable pre_post_covid "Pre-/Post-Covid Indicator"
label variable pre_covid "Pre-Covid Mean of Court Budget as % of Gov't Exp."
label variable post_covid "Post-Covid Mean of Court Budget as % of Gov't Exp."
label variable pre_post_covid_means "Pre-/Post-Covid Mean of Court Budget as % of Gov't Exp."
//Save as .dta
save "${cleaned}/CLEANED.dta", replace